package org.fuseri.modulelanguageschool.lecture;

import org.fuseri.model.dto.common.Result;
import org.fuseri.model.dto.lecture.LectureDto;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

/**
 * This class represents a RESTful controller for Lecture resources.
 * It handles incoming HTTP requests related to lectures, and delegates them to the appropriate service method.
 */
@RestController
@RequestMapping("/lectures")
public class LectureController {
    private final LectureService service;

    private final LectureMapper mapper;

    /**
     * Constructs a new LectureController instance with the given dependencies.
     *
     * @param service the LectureService to be used for handling lecture-related operations
     * @param mapper  the LectureMapper to be used for mapping between DTOs and entities
     */
    @Autowired
    public LectureController(LectureService service, LectureMapper mapper) {
        this.service = service;
        this.mapper = mapper;
    }

    /**
     * Creates a new lecture resource by delegating to the LectureService's create method.
     *
     * @param lecture the LectureDto representing the lecture to be created
     * @return the LectureDto representing the newly created lecture
     */
    @PostMapping
    public LectureDto create(@RequestBody LectureDto lecture) {
        return mapper.toDto(service.create(mapper.fromDto(lecture)));
    }

    /**
     * Retrieves a paginated list of lecture resources by delegating to the LectureService's findAll method.
     *
     * @param page the page number to retrieve
     * @return the Result object containing a list of LectureDtos and pagination information
     */
    @GetMapping
    public Result<LectureDto> findAll(@RequestParam int page) {
        return mapper.toResult(service.findAll(page));
    }
}